@@ -12,10 +12,6 @@
 #include <wlr/xwayland.h>
 #endif
 
-#include "output.h"
-#include "seat.h"
-#include "view.h"
-
 enum cg_multi_output_mode {
 	CAGE_MULTI_OUTPUT_MODE_EXTEND,
 	CAGE_MULTI_OUTPUT_MODE_LAST,
@@ -25,6 +21,8 @@ struct cg_server {
 	struct wl_display *wl_display;
 	struct wl_list views;
 	struct wlr_backend *backend;
+	struct wlr_renderer *renderer;
+	struct wlr_allocator *allocator;
 
 	struct cg_seat *seat;
 	struct wlr_idle *idle;
@@ -34,23 +32,27 @@ struct cg_server {
 
 	enum cg_multi_output_mode output_mode;
 	struct wlr_output_layout *output_layout;
+	struct wlr_scene *scene;
 	/* Includes disabled outputs; depending on the output_mode
 	 * some outputs may be disabled. */
 	struct wl_list outputs; // cg_output::link
 	struct wl_listener new_output;
+	struct wl_listener output_layout_change;
 
 	struct wl_listener xdg_toplevel_decoration;
 	struct wl_listener new_xdg_shell_surface;
+
+	struct wl_listener new_virtual_keyboard;
+	struct wl_listener new_virtual_pointer;
 #if CAGE_HAS_XWAYLAND
 	struct wl_listener new_xwayland_surface;
 #endif
+	struct wlr_output_manager_v1 *output_manager_v1;
+	struct wl_listener output_manager_apply;
+	struct wl_listener output_manager_test;
 
 	bool xdg_decoration;
 	bool allow_vt_switch;
-	enum wl_output_transform output_transform;
-#ifdef DEBUG
-	bool debug_damage_tracking;
-#endif
 };
 
 #endif
