@@ -9,24 +9,12 @@
 
 struct cg_xdg_shell_view {
 	struct cg_view view;
-	struct wlr_xdg_surface *xdg_surface;
+	struct wlr_xdg_toplevel *xdg_toplevel;
 
 	struct wl_listener destroy;
 	struct wl_listener unmap;
 	struct wl_listener map;
-	struct wl_listener commit;
 	struct wl_listener request_fullscreen;
-	struct wl_listener new_popup;
-};
-
-struct cg_xdg_popup {
-	struct cg_view_child view_child;
-	struct wlr_xdg_popup *wlr_popup;
-
-	struct wl_listener destroy;
-	struct wl_listener map;
-	struct wl_listener unmap;
-	struct wl_listener new_popup;
 };
 
 struct cg_xdg_decoration {
